"""
Tests for casa_envoy.foundation
"""
from pathlib import Path
from unittest.mock import patch

from casa_envoy.schema import AbstractTextFile

from casa_envoy.foundation import RestoreFoundation


parameters = expected_settings = {
    "useCasa": False,
    "homeForReprocessing": "/home/casa/packages/pipeline/current",
    "rootDirectory": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool",
    "processingDirectory": "tmpo1ca1pp_",
    "parent_path": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmpo1ca1pp_",
    "metadata": "test/input_files/restore.json",
    "ppr": "test/input_files/PPR.xml",
    "product_type": "restore",
}

test_restore_metadata = AbstractTextFile(
    filename="test/input_files/restore.json",
    content=Path("test/input_files/restore.json").read_text(),
)

foundation = RestoreFoundation(parameters=parameters, metadata=test_restore_metadata)


class TestRestoreFoundation:
    @patch("os.chdir")
    def test_data_foundation(self, mock_chdir):
        with patch("casa_envoy.foundation.RestoreFoundation.extract_cal") as extract:
            with patch("casa_envoy.foundation.RestoreFoundation.set_permissions") as permissions:
                foundation.data_foundation()
                assert mock_chdir.call_count == 1

    @patch("pathlib.Path.exists", return_value=True)
    @patch("tarfile.open")
    def test_extract_cal(self, mock_tar, mock_path):
        foundation.extract_cal()
        assert mock_tar.call_count == 1

    @patch("os.path.join")
    @patch("os.chmod")
    @patch("os.walk")
    def test_set_permissions(self, mock_walk, mock_chmod, mock_join):
        foundation.set_permissions()
        assert mock_walk.call_count == 1
