"""
A Quasar is a radio emitting active galactic nucleus (i.e. an actively feeding supermassive black hole).
Radio Astronomy for the win!!!!
"""
import argparse
import logging
import os
import pathlib
import sys

from pycapo import CapoConfig

from vela.emulators import CalibrationEmulator
from vela.emulators import ImagingEmulator

"""
The Vela system allows for testing Workspaces workflows without submitting to CASA on the cluster.
"""

logger = logging.getLogger("vela")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


def _get_settings(cwd: pathlib.Path):
    use_casa = CapoConfig().getboolean("edu.nrao.archive.workspaces.ProcessingSettings.useCasa")
    casa_home = (
        CapoConfig().settings("edu.nrao.archive.workflow.config.CasaVersions").homeForReprocessing
    )

    root_dir = str(cwd.parent)
    processing_dir = str(cwd.stem)

    return {
        "useCasa": use_casa,
        "homeForReprocessing": casa_home,
        "rootDirectory": root_dir,
        "processingDirectory": processing_dir,
    }


def parser() -> argparse.ArgumentParser:
    arg_parser = argparse.ArgumentParser(
        description="Workspaces VELA processing launcher",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    arg_parser.add_argument(
        "--standard-cal",
        nargs=2,
        action="store",
        required=False,
        help="run the standard calibration pipeline",
    )
    arg_parser.add_argument(
        "--standard-img",
        nargs=2,
        action="store",
        required=False,
        help="run the standard imaging pipeline",
    )
    return arg_parser


def main():
    args = parser().parse_args()

    path = os.getcwd()
    settings = _get_settings(pathlib.Path(path))
    if args.standard_cal is not None:
        metadata = args.standard_cal[0]
        ppr = args.standard_cal[1]
        emulator = CalibrationEmulator(metadata, ppr)
    elif args.standard_img is not None:
        metadata = args.standard_img[0]
        ppr = args.standard_img[1]
        emulator = ImagingEmulator(metadata, ppr)
    else:
        logger.info("ARGUMENT ERROR: no valid argument was provided.")

    emulator.setup_environment(settings)
    emulator.run()
    emulator.check_logs(parent_path=path)
    os.chdir(path)
